-- Appearances from World of Warcraft (v.1.x)

--
-- LOCAL VARIABLES
--

local ALL = SetCollector.ALL
local ANY = SetCollector.ANY

-- Armor Type
local CLOTH = SetCollector.CLOTH
local LEATHER = SetCollector.LEATHER
local MAIL = SetCollector.MAIL
local PLATE = SetCollector.PLATE
local ANY_ARMOR = SetCollector.ANY_ARMOR

-- Classes
local DEATHKNIGHT = SetCollector.DEATHKNIGHT
local DEMONHUNTER = SetCollector.DEMONHUNTER
local DRUID = SetCollector.DRUID
local HUNTER = SetCollector.HUNTER
local MAGE = SetCollector.MAGE
local MONK = SetCollector.MONK
local PALADIN = SetCollector.PALADIN
local PRIEST = SetCollector.PRIEST
local ROGUE = SetCollector.ROGUE
local SHAMAN = SetCollector.SHAMAN
local WARLOCK = SetCollector.WARLOCK
local WARRIOR = SetCollector.WARRIOR
local ANY_CLASS = SetCollector.ANY_CLASS

-- Factions
local ALLIANCE = SetCollector.ALLIANCE
local HORDE = SetCollector.HORDE
local ANY_FACTION = SetCollector.ANY_FACTION

-- Obtainable
local OBTAIN = SetCollector.OBTAIN
local NO_OBTAIN = SetCollector.NO_OBTAIN

-- Useable as Transmog
local TRANSMOG = SetCollector.TRANSMOG
local NO_TRANSMOG = SetCollector.NO_TRANSMOG

-- Locations
local NO_LOCATION = nil

--
-- LOCAL FUNCTIONS
--

local function A(...) return SetCollector:CreateAppearance(...) end
local function CreateSet(...) return SetCollector:CreateSet(...) end
local function CreateVariant(...) return SetCollector:CreateVariant(...) end
local function IncludeSet(...) return SetCollector:IncludeSet(...) end
local function AddSetsToDatabase(...) return SetCollector:AddSetsToDatabase(...) end

local function GetCraftedAppearances()
    local COLLECTION, VERSION = SetCollector.CRAFTED, 70000
    local sets = {
        CreateSet(COLLECTION,10001,"PLACEHOLDER",CLOTH,ANY_CLASS,ANY_FACTION,NO_LOCATION,
            CreateVariant("1",TRANSMOG,A(5657,8336)),
            CreateVariant("2",TRANSMOG,A(5772,8514)),
            CreateVariant("3",TRANSMOG,A(5773,8515)),
            CreateVariant("4",TRANSMOG,A(5656,8335))
        ),
        CreateSet(COLLECTION,10001,"PLACEHOLDER",LEATHER,ANY_CLASS,ANY_FACTION,NO_LOCATION,
            CreateVariant("1",TRANSMOG,A(5657,8336)),
            CreateVariant("2",TRANSMOG,A(5772,8514)),
            CreateVariant("3",TRANSMOG,A(5773,8515)),
            CreateVariant("4",TRANSMOG,A(5656,8335))
        ),
        CreateSet(COLLECTION,10001,"PLACEHOLDER",MAIL,ANY_CLASS,ANY_FACTION,NO_LOCATION,
            CreateVariant("1",TRANSMOG,A(),A(),A(1234,1285)),   -- Copper chain
            CreateVariant("2",TRANSMOG,A(),A(),A(982,981),A(980,979),A(1235,1286),A(981,980),A(1236,1287)),   -- Runed Copper
            CreateVariant("1",TRANSMOG,A(),A(1239,1290),A(984,983),A(),A(),A(),A(983,982),A(1450,2357)),   -- Rough Bronze
            CreateVariant("2",TRANSMOG,A(),A(1240,1291),A(986,986),A(),A(1242,1293),A(),A(1457,3967),A(1241,1292)),   -- Silvered Bronze
            CreateVariant("3",TRANSMOG,A(1363,1445),A(1365,1447),A(1369,1451),A(1362,1444),A(1244,1295),A(),A(1367,1449),A(1243,1294)),   -- Green Iron
            CreateVariant("4",TRANSMOG,A(1364,1446),A(1366,1448),A(1370,1452),A(1955,2230),A(),A(),A(1368,1450),A(1372,1454)),   -- Golden Scale
            CreateVariant("5",TRANSMOG,A(1504,2976)),   -- Mitril
            CreateVariant("6",TRANSMOG,A(),A(2544,2977),A(),A(569,2969),A(),A(),A(205,2966))   -- Mitril Scale
        ),
        CreateSet(COLLECTION,10001,"PLACEHOLDER",PLATE,ANY_CLASS,ANY_FACTION,NO_LOCATION,
            CreateVariant("1",TRANSMOG,A(2484,2968)),   -- Steel Plate
            CreateVariant("2",TRANSMOG,A(2546,2979),A(2537,2964),A(1920,2975),A(),A(2538,2965),A(),A(2539,2967),A(2545,2978)),   -- Heavy Mitril
            CreateVariant("3",TRANSMOG,A(3539,4408),A(),A(3537,4404),A(3538,4406),A(),A(3259,4405),A(3540,4409),A(2756,4407)),   -- Thorium
            CreateVariant("4",TRANSMOG,A(3550,4421),A(3551,4422),A(3546,4417),A(3548,4419),A(),A(3547,4418),A(3552,4423),A(3549,4420)),   -- Imperial
            CreateVariant("5",TRANSMOG,A(3844,7623),A(3423,4196),A(3422,4195),A(4630,7061),A(5392,7631),A(),A(5104,7060),A(5281,7905))    -- Dark Iron
        ),
    }
    AddSetsToDatabase(VERSION, COLLECTION, sets)
end

local function GetDungeonAppearances()
    local COLLECTION, VERSION = SetCollector.DUNGEON, 70000
    local sets = {
        -- Dungeon 1
        CreateSet(COLLECTION,10101,"DR_DG_01",LEATHER,DRUID,ANY_FACTION,NO_LOCATION,
            CreateVariant("REPLICA",TRANSMOG,A(4920,39643),A(4918,39644),A(4908,39647),A(4914,39645),A(4917,39646),A(4916,39649),A(4919,39650),A(4915,39648))
            --CreateVariant("ORIGINAL",TRANSMOG,A(4920,6851),A(4918,6849),A(4908,6837),A(4914,6845),A(4917,6848),A(4916,6847),A(4919,6850),A(4915,6846))
        ),
        CreateSet(COLLECTION,10101,"HU_DG_01",MAIL,HUNTER,ANY_FACTION,NO_LOCATION,
            CreateVariant("REPLICA",TRANSMOG,A(4880,39680),A(4882,39678),A(4877,39675),A(4884,39682),A(4879,39676),A(4883,39679),A(4881,39681),A(4878,39677))
            --CreateVariant("ORIGINAL",TRANSMOG,A(4880,6808),A(4882,6810),A(4877,6805),A(4884,6812),A(4879,6807),A(4883,6811),A(4881,6809),A(4878,6806))
        ),
        CreateSet(COLLECTION,10101,"MA_DG_01",CLOTH,MAGE,ANY_FACTION,NO_LOCATION,
            CreateVariant("REPLICA",TRANSMOG,A(4889,39597),A(4891,39600),A(4890,39599),A(4886,39602),A(4887,39596),A(4888,39601),A(4008,39598),A(4885,39595))
            --CreateVariant("ORIGINAL",TRANSMOG,A(4889,6817),A(4891,6820),A(4890,6819),A(4886,6814),A(4887,6815),A(4888,6816),A(4008,6818),A(4885,6813))
        ),
        CreateSet(COLLECTION,10101,"PA_DG_01",PLATE,PALADIN,ANY_FACTION,NO_LOCATION,
            CreateVariant("REPLICA",TRANSMOG,A(4926,39712),A(4928,39713),A(4925,39711),A(4921,39709),A(4923,39708),A(4922,39707),A(4927,39710),A(4924,39714))
        ),
        CreateSet(COLLECTION,10101,"PR_DG_01",CLOTH,PRIEST,ANY_FACTION,NO_LOCATION,
            CreateVariant("REPLICA",TRANSMOG,A(4895,39612),A(4897,39611),A(4892,39616),A(4899,39618),A(4894,39615),A(4898,39614),A(4896,39613),A(4893,39617))
        ),
        CreateSet(COLLECTION,10101,"RO_DG_01",LEATHER,ROGUE,ANY_FACTION,NO_LOCATION,
            CreateVariant("REPLICA",TRANSMOG,A(4909,39665),A(4910,39666),A(4685,6852),A(3879,39660),A(4913,39662),A(567,39664),A(4911,39663),A(4912,39661))
        ),
        CreateSet(COLLECTION,10101,"SH_DG_01",MAIL,SHAMAN,ANY_FACTION,NO_LOCATION,
            CreateVariant("REPLICA",TRANSMOG,A(4870,39691),A(4872,39693),A(4869,39695),A(4874,39694),A(4875,39696),A(4876,39698),A(4871,39692),A(4873,39697))
        ),
        CreateSet(COLLECTION,10101,"WK_DG_01",CLOTH,WARLOCK,ANY_FACTION,NO_LOCATION,
            CreateVariant("REPLICA",TRANSMOG,A(4900,39632),A(4903,39631),A(4902,39630),A(4905,39634),A(4907,39628),A(4904,39627),A(4901,39633),A(4906,39629))
        ),
        CreateSet(COLLECTION,10101,"WR_DG_01",PLATE,WARRIOR,ANY_FACTION,NO_LOCATION,
            CreateVariant("REPLICA",TRANSMOG,A(4930,39727),A(4932,39730),A(4929,39728),A(4934,39726),A(4936,39725),A(4935,39724),A(4931,39729),A(4933,39723))
        ),

        -- Dungeon 2
        CreateSet(COLLECTION,10102,"DR_DG_02",LEATHER,DRUID,ANY_FACTION,NO_LOCATION,
            CreateVariant("REPLICA",TRANSMOG,A(5929,39654),A(5932,39652),A(5933,39657),A(5928,39658),A(5930,39653),A(5926,39651),A(5931,39655),A(5927,39656))
            --CreateVariant("ORIGINAL",TRANSMOG,A(5929,8723),A(5932,8726),A(5933,8727),A(5928,8722),A(5930,8724),A(5926,8720),A(5931,8725),A(5927,8721))
        ),
        CreateSet(COLLECTION,10102,"HU_DG_02",MAIL,HUNTER,ANY_FACTION,NO_LOCATION,
            CreateVariant("REPLICA",TRANSMOG,A(5880,39689),A(5882,39686),A(5884,39687),A(5879,39688),A(5881,39683),A(5878,39690),A(5883,39685),A(5885,39684))
            --CreateVariant("ORIGINAL",TRANSMOG,A(5880,8674),A(5882,8676),A(5884,8678),A(5879,8673),A(5881,8675),A(5878,8672),A(5883,8677),A(5885,8679))
        ),
        CreateSet(COLLECTION,10102,"MA_DG_02",CLOTH,MAGE,ANY_FACTION,NO_LOCATION,
            CreateVariant("REPLICA",TRANSMOG,A(5889,39605),A(5892,39608),A(5893,39607),A(5887,39610),A(5890,39604),A(5886,39609),A(5891,39606),A(5888,39603))
            --CreateVariant("ORIGINAL",TRANSMOG,A(5889,8683),A(5892,8686),A(5893,8687),A(5887,8681),A(5890,8684),A(5886,8680),A(5891,8685),A(5888,8682))
        ),
        CreateSet(COLLECTION,10102,"PA_DG_02",PLATE,PALADIN,ANY_FACTION,NO_LOCATION,
            CreateVariant("REPLICA",TRANSMOG,A(5915,39717),A(5917,39721),A(5913,39718),A(5912,39722),A(5914,39719),A(5910,39716),A(5916,39720),A(5911,39715))
        ),
        CreateSet(COLLECTION,10102,"PR_DG_02",CLOTH,PRIEST,ANY_FACTION,NO_LOCATION,
            CreateVariant("REPLICA",TRANSMOG,A(5904,39623),A(5906,39620),A(5907,39619),A(5903,39622),A(5905,39624),A(5902,39625),A(5909,39621),A(5908,39626))
        ),
        CreateSet(COLLECTION,10102,"RO_DG_02",LEATHER,ROGUE,ANY_FACTION,NO_LOCATION,
            CreateVariant("REPLICA",TRANSMOG,A(5873,39668),A(5876,39672),A(5877,39674),A(5872,39669),A(5874,39671),A(5870,39670),A(5875,39673),A(5871,39667))
        ),
        CreateSet(COLLECTION,10102,"SH_DG_02",MAIL,SHAMAN,ANY_FACTION,NO_LOCATION,
            CreateVariant("REPLICA",TRANSMOG,A(5920,39699),A(5924,39704),A(5925,39705),A(5918,39701),A(5922,39700),A(5921,39702),A(5923,39706),A(5919,39703))
        ),
        CreateSet(COLLECTION,10102,"WK_DG_02",CLOTH,WARLOCK,ANY_FACTION,NO_LOCATION,
            CreateVariant("REPLICA",TRANSMOG,A(5898,39635),A(5897,39639),A(5899,39642),A(5895,39637),A(5901,39641),A(5894,39638),A(5896,39636),A(5900,39640))
        ),
        CreateSet(COLLECTION,10102,"WR_DG_02",PLATE,WARRIOR,ANY_FACTION,NO_LOCATION,
            CreateVariant("REPLICA",TRANSMOG,A(5867,39735),A(5869,39737),A(5865,39733),A(5864,39732),A(5866,39734),A(5862,39738),A(2868,39736),A(5863,39731))
        ),

        -- Dungeon 3
        CreateSet(COLLECTION,10103,"DR_DG_03",LEATHER,DRUID,ANY_FACTION,NO_LOCATION,
            CreateVariant("DR_DG_03",TRANSMOG,A(7162,12416),A(6923,12028),A(7080,12324),A(6855,11916),A(6998,12118))
        ),
        CreateSet(COLLECTION,10103,"HU_DG_03",MAIL,HUNTER,ANY_FACTION,NO_LOCATION,
            CreateVariant("HU_DG_03",TRANSMOG,A(7121,12367),A(6961,12076),A(7101,12345),A(6856,11922),A(6999,12119))
        ),
        CreateSet(COLLECTION,10103,"MA_DG_03",CLOTH,MAGE,ANY_FACTION,NO_LOCATION,
            CreateVariant("MA_DG_03",TRANSMOG,A(7122,12368),A(6924,12029),A(7102,12346),A(6874,11942),A(6981,12097))
        ),
        CreateSet(COLLECTION,10103,"PA_DG_03",PLATE,PALADIN,ANY_FACTION,NO_LOCATION,
            CreateVariant("PA_DG_03",TRANSMOG,A(7123,12369),A(6925,12030),A(7081,12325),A(6890,11963),A(6982,12098))
        ),
        CreateSet(COLLECTION,10103,"PR_DG_03",CLOTH,PRIEST,ANY_FACTION,NO_LOCATION,
            CreateVariant("PR_DG_03",TRANSMOG,A(7195,12457),A(6944,12058),A(7103,12347),A(6891,11964),A(7000,12120))
        ),
        CreateSet(COLLECTION,10103,"RO_DG_03",LEATHER,ROGUE,ANY_FACTION,NO_LOCATION,
            CreateVariant("RO_DG_03",TRANSMOG,A(7196,12458),A(6945,12059),A(7082,12326),A(6875,11943),A(7019,12146))
        ),
        CreateSet(COLLECTION,10103,"SH_DG_03",MAIL,SHAMAN,ANY_FACTION,NO_LOCATION,
            CreateVariant("SH_DG_03",TRANSMOG,A(7163,12417),A(6962,12077),A(7104,12348),A(6876,11944),A(7020,12147))
        ),
        CreateSet(COLLECTION,10103,"WK_DG_03",CLOTH,WARLOCK,ANY_FACTION,NO_LOCATION,
            CreateVariant("WK_DG_03",TRANSMOG,A(7197,12459),A(6946,12060),A(7105,12349),A(6892,11965),A(7035,12168))
        ),
        CreateSet(COLLECTION,10103,"WR_DG_03",PLATE,WARRIOR,ANY_FACTION,NO_LOCATION,
            CreateVariant("WR_DG_03",TRANSMOG,A(7164,15418),A(6963,12078),A(7083,12327),A(6857,11923),A(7036,12191))
        ),

        -- Dungeon 4
        IncludeSet(COLLECTION,10104,1450,CLOTH,ANY_CLASS,ANY_FACTION),
        --CreateSet(COLLECTION,10104,"DG_CLOTH_03",CLOTH,ANY_CLASS,ANY_FACTION,NO_LOCATION,
        --    CreateVariant("DG_CLOTH_03",TRANSMOG,A(7071,12315),A(6956,12071),A(7069,12313),A(6852,11913),A(7018,12145))
        --),
        CreateSet(COLLECTION,10104,"DG_LEATHER_03",LEATHER,ANY_CLASS,ANY_FACTION,NO_LOCATION,
            CreateVariant("DG_LEATHER_03",TRANSMOG,A(7098,12342),A(6957,12072),A(7116,12362),A(6888,11960),A(6980,12096))
        ),
        CreateSet(COLLECTION,10104,"DG_MAIL_03",MAIL,ANY_CLASS,ANY_FACTION,NO_LOCATION,
            CreateVariant("DG_MAIL_03",TRANSMOG,A(7070,12314),A(6920,12009),A(7184,12446),A(6887,11958),A(7030,12162))
        ),
        CreateSet(COLLECTION,10104,"DG_PLATE_03",PLATE,ANY_CLASS,ANY_FACTION,NO_LOCATION,
            CreateVariant("DG_PLATE_03",TRANSMOG,A(7099,12343),A(6941,12055),A(7186,12448),A(6870,11938),A(6996,12116))
        )
    }
    AddSetsToDatabase(VERSION, COLLECTION, sets)
end

local function GetLegendaries()
    local COLLECTION, VERSION = SetCollector.RAID, 70000
    
    local sets = {
        CreateSet(COLLECTION,10101,"LG_60",ANY_ARMOR,ANY_CLASS,ANY_FACTION,NO_LOCATION,
            CreateVariant("LG_60",TRANSMOG,A(5131,7098))
        ),
    }
    AddSetsToDatabase(VERSION, COLLECTION, sets)
end

local function GetRaidAppearances()
    local COLLECTION, VERSION = SetCollector.RAID, 70000

    local sets = {
        -- Molten Core
        IncludeSet(COLLECTION,10101,928,LEATHER,DRUID,ANY_FACTION),
        IncludeSet(COLLECTION,10101,917,MAIL,HUNTER,ANY_FACTION),
        IncludeSet(COLLECTION,10101,910,CLOTH,MAGE,ANY_FACTION),
        IncludeSet(COLLECTION,10101,902,PLATE,PALADIN,ANY_FACTION),
        IncludeSet(COLLECTION,10101,357,CLOTH,PRIEST,ANY_FACTION),
        IncludeSet(COLLECTION,10101,894,LEATHER,ROGUE,ANY_FACTION),
        IncludeSet(COLLECTION,10101,876,MAIL,SHAMAN,ANY_FACTION),
        IncludeSet(COLLECTION,10101,868,CLOTH,WARLOCK,ANY_FACTION),
        IncludeSet(COLLECTION,10101,853,PLATE,WARRIOR,ANY_FACTION),
        -- Blackwing Lair
        IncludeSet(COLLECTION,10102,927,LEATHER,DRUID,ANY_FACTION),
        IncludeSet(COLLECTION,10102,916,MAIL,HUNTER,ANY_FACTION),
        IncludeSet(COLLECTION,10102,909,CLOTH,MAGE,ANY_FACTION),
        IncludeSet(COLLECTION,10102,901,PLATE,PALADIN,ANY_FACTION,
            CreateVariant("RECOLOR",TRANSMOG,A(6951,12066),A(6894,11967),A(7010,12137),A(6865,11932),A(6847,11907),A(6901,11974),A(6930,12037),A(7096,12340))
        ),
        IncludeSet(COLLECTION,10102,356,CLOTH,PRIEST,ANY_FACTION),
        IncludeSet(COLLECTION,10102,893,LEATHER,ROGUE,ANY_FACTION),
        IncludeSet(COLLECTION,10102,875,MAIL,SHAMAN,ANY_FACTION),
        IncludeSet(COLLECTION,10102,867,CLOTH,WARLOCK,ANY_FACTION),
        IncludeSet(COLLECTION,10102,852,PLATE,WARRIOR,ANY_FACTION),
        -- Naxxramas
        IncludeSet(COLLECTION,10103,924,LEATHER,DRUID,ANY_FACTION),
        IncludeSet(COLLECTION,10103,914,MAIL,HUNTER,ANY_FACTION),
        IncludeSet(COLLECTION,10103,907,CLOTH,MAGE,ANY_FACTION),
        IncludeSet(COLLECTION,10103,899,PLATE,PALADIN,ANY_FACTION),
        IncludeSet(COLLECTION,10103,355,CLOTH,PRIEST,ANY_FACTION),
        IncludeSet(COLLECTION,10103,891,LEATHER,ROGUE,ANY_FACTION),
        IncludeSet(COLLECTION,10103,873,MAIL,SHAMAN,ANY_FACTION),
        IncludeSet(COLLECTION,10103,865,CLOTH,WARLOCK,ANY_FACTION),
        IncludeSet(COLLECTION,10103,850,PLATE,WARRIOR,ANY_FACTION),
        -- Temple of Ahn'Qiraj
        IncludeSet(COLLECTION,10104,926,LEATHER,DRUID,ANY_FACTION),
        IncludeSet(COLLECTION,10104,915,MAIL,HUNTER,ANY_FACTION),
        IncludeSet(COLLECTION,10104,908,CLOTH,MAGE,ANY_FACTION),
        IncludeSet(COLLECTION,10104,900,PLATE,PALADIN,ANY_FACTION),
        IncludeSet(COLLECTION,10104,358,CLOTH,PRIEST,ANY_FACTION),
        IncludeSet(COLLECTION,10104,892,LEATHER,ROGUE,ANY_FACTION),
        IncludeSet(COLLECTION,10104,874,MAIL,SHAMAN,ANY_FACTION),
        IncludeSet(COLLECTION,10104,866,CLOTH,WARLOCK,ANY_FACTION),
        IncludeSet(COLLECTION,10104,851,PLATE,WARRIOR,ANY_FACTION),
    }
    AddSetsToDatabase(VERSION, COLLECTION, sets)
end

--
--    GLOBAL FUNCTIONS
--

function SetCollector:GetVersion01Appearances(expansion)
    if expansion.v01 then
        -- Common
        --GetLegendaries()
        GetDungeonAppearances()
        GetRaidAppearances()
    end
end

function SetCollector:GetVersion01Status()
    return SetCollector:GetExpansionStatus("1")
end

function SetCollector:SetVersion01Status()
    SetCollector:SetExpansionStatus("1")
end
