-- Appearances from Legion (v.7.x)

--
-- LOCAL VARIABLES
--

local ALL = SetCollector.ALL
local ANY = SetCollector.ANY

-- Armor Type
local CLOTH = SetCollector.CLOTH
local LEATHER = SetCollector.LEATHER
local MAIL = SetCollector.MAIL
local PLATE = SetCollector.PLATE
local ANY_ARMOR = SetCollector.ANY_ARMOR

-- Classes
local DEATHKNIGHT = SetCollector.DEATHKNIGHT
local DEMONHUNTER = SetCollector.DEMONHUNTER
local DRUID = SetCollector.DRUID
local HUNTER = SetCollector.HUNTER
local MAGE = SetCollector.MAGE
local MONK = SetCollector.MONK
local PALADIN = SetCollector.PALADIN
local PRIEST = SetCollector.PRIEST
local ROGUE = SetCollector.ROGUE
local SHAMAN = SetCollector.SHAMAN
local WARLOCK = SetCollector.WARLOCK
local WARRIOR = SetCollector.WARRIOR
local ANY_CLASS = SetCollector.ANY_CLASS

-- Factions
local ALLIANCE = SetCollector.ALLIANCE
local HORDE = SetCollector.HORDE
local ANY_FACTION = SetCollector.ANY_FACTION

-- Obtainable
local OBTAIN = SetCollector.OBTAIN
local NO_OBTAIN = SetCollector.NO_OBTAIN

-- Useable as Transmog
local TRANSMOG = SetCollector.TRANSMOG
local NO_TRANSMOG = SetCollector.NO_TRANSMOG

-- Locations
local NO_LOCATION = nil

--
-- LOCAL FUNCTIONS
--

local function A(...) return SetCollector:CreateAppearance(...) end
local function CreateSet(...) return SetCollector:CreateSet(...) end
local function CreateVariant(...) return SetCollector:CreateVariant(...) end
local function IncludeSet(...) return SetCollector:IncludeSet(...) end
local function AddSetsToDatabase(...) return SetCollector:AddSetsToDatabase(...) end

local function GetCraftedAppearances()
    local COLLECTION, VERSION = SetCollector.CRAFTED, 70000
    local sets = {
        CreateSet(COLLECTION,10701,"CR_PLATE_100",PLATE,ANY_CLASS,ANY_FACTION,NO_LOCATION,
            CreateVariant("CR_PLATE_100",TRANSMOG,A(27327,80888),A(27329,80890),A(27325,80885),A(27330,80892),A(27326,80887),A(27323,80891),A(27328,80889),A(27324,80886))
        ),
        CreateSet(COLLECTION,10702,"PLACEHOLDER",PLATE,ANY_CLASS,ANY_FACTION,NO_LOCATION,
            CreateVariant("PLACEHOLDER",TRANSMOG,A(27133,80856),A(27135,80858),A(27131,80853),A(27136,80860),A(27132,80855),A(27129,80859),A(27134,80857),A(27130,80854))
        ),
    }
    AddSetsToDatabase(VERSION, COLLECTION, sets)
end

local function GetDungeonAppearances()
    local COLLECTION, VERSION = SetCollector.DUNGEON, 70000
    local LOCATION_01, LOCATION_02, LOCATION_03, LOCATION_04 = "LOC_DG_0701", "LOC_DG_0702", "LOC_DG_0703", "LOC_DG_0704"
    local sets = {
        CreateSet(COLLECTION,10701,"DG_CLOTH_0701",CLOTH,ANY_CLASS,ANY_FACTION,NO_LOCATION,
            CreateVariant("LOC_DG_0701",TRANSMOG,A(27191),A(27194),A(27195),A(27193),A(27190),A(27187),A(27192),A(27215))
        ),
        CreateSet(COLLECTION,10701,"DG_LEATHER_0701",LEATHER,ANY_CLASS,ANY_FACTION,NO_LOCATION,
            CreateVariant("LOC_DG_0701",TRANSMOG,A(26906),A(26908),A(26904),A(26909),A(26905),A(26902),A(26907),A(26903))
        ),
        CreateSet(COLLECTION,10701,"DG_MAIL_0701",MAIL,ANY_CLASS,ANY_FACTION,NO_LOCATION,
            CreateVariant("LOC_DG_0701",TRANSMOG,A(),A(27284),A(27281),A(27286),A(27282),A(27279),A(27285),A(27264))
        ),
        CreateSet(COLLECTION,10701,"DG_PLATE_0701",PLATE,ANY_CLASS,ANY_FACTION,NO_LOCATION,
            CreateVariant("LOC_DG_0701",TRANSMOG,A(27079),A(27081),A(27077),A(27082),A(27078),A(27075),A(27080),A(27076))
        ),
        CreateSet(COLLECTION,10702,"DG_CLOTH_0701",CLOTH,ANY_CLASS,ANY_FACTION,NO_LOCATION,
            CreateVariant("LOC_DG_0702",TRANSMOG,A(27544),A(27547),A(27549),A(27548),A(27543),A(27540),A(27545),A(27215))
        ),
        CreateSet(COLLECTION,10702,"DG_LEATHER_0701",LEATHER,ANY_CLASS,ANY_FACTION,NO_LOCATION,
            CreateVariant("LOC_DG_0702",TRANSMOG,A(26925),A(26927),A(26923),A(26928),A(26924),A(26921),A(26926),A(26922))
        ),
        CreateSet(COLLECTION,10702,"DG_MAIL_0701",MAIL,ANY_CLASS,ANY_FACTION,NO_LOCATION,
            CreateVariant("LOC_DG_0702",TRANSMOG,A(27267),A(27268),A(27265),A(27270),A(27266),A(27263),A(27269),A(27264))
        ),
        CreateSet(COLLECTION,10702,"DG_PLATE_0701",PLATE,ANY_CLASS,ANY_FACTION,NO_LOCATION,
            CreateVariant("LOC_DG_0702",TRANSMOG,A(27100),A(27102),A(27098),A(27103),A(27099),A(27096),A(27101),A(27097))
        ),
        CreateSet(COLLECTION,10703,"DG_CLOTH_0701",CLOTH,ANY_CLASS,ANY_FACTION,NO_LOCATION,
            CreateVariant("LOC_DG_0703",TRANSMOG,A(27218),A(27221),A(27222),A(27220),A(27217),A(27214),A(27219),A(27215))
        ),
        CreateSet(COLLECTION,10703,"DG_LEATHER_0701",LEATHER,ANY_CLASS,ANY_FACTION,NO_LOCATION,
            CreateVariant("LOC_DG_0703",TRANSMOG,A(27249),A(27251),A(27247),A(27252),A(27248),A(27245),A(27250),A(27246))
        ),
        CreateSet(COLLECTION,10703,"DG_MAIL_0701",MAIL,ANY_CLASS,ANY_FACTION,NO_LOCATION,
            CreateVariant("LOC_DG_0703",TRANSMOG,A(),A(27464),A(27460),A(27465),A(27461),A(27458),A(27463),A(27459))
        ),
        CreateSet(COLLECTION,10703,"DG_PLATE_0701",PLATE,ANY_CLASS,ANY_FACTION,NO_LOCATION,
            CreateVariant("LOC_DG_0703",TRANSMOG,A(27117),A(27119),A(27115),A(27120),A(27116),A(27113),A(27118),A(27114))
        ),
        CreateSet(COLLECTION,10704,"DG_CLOTH_0701",CLOTH,ANY_CLASS,ANY_FACTION,LOCATION_04,
            CreateVariant("LOC_DG_0704",TRANSMOG,A(33901),A(33904),A(33903),A(33898),A(33896),A(33900),A(33897))
        ),
        CreateSet(COLLECTION,10704,"DG_LEATHER_0701",LEATHER,ANY_CLASS,ANY_FACTION,LOCATION_04,
            CreateVariant("LOC_DG_0704",TRANSMOG,A(33974),A(33976),A(33972),A(33977),A(33973),A(33970),A(33975),A(33971))
        ),
        CreateSet(COLLECTION,10704,"DG_MAIL_0701",MAIL,ANY_CLASS,ANY_FACTION,LOCATION_04,
            CreateVariant("LOC_DG_0704",TRANSMOG,A(34008),A(34010),A(34006),A(34011),A(34007),A(34004),A(34009),A(34005))
        ),
        CreateSet(COLLECTION,10704,"DG_PLATE_0701",PLATE,ANY_CLASS,ANY_FACTION,LOCATION_04,
            CreateVariant("LOC_DG_0704",TRANSMOG,A(34050),A(34052),A(34048),A(34053),A(34049),A(34046),A(34051),A(34047))
        ),
        -- Seat of the Triumvirate
        IncludeSet(COLLECTION,10705,1471,CLOTH,ANY_CLASS,ANY_FACTION),
        IncludeSet(COLLECTION,10705,1470,LEATHER,ANY_CLASS,ANY_FACTION),
        IncludeSet(COLLECTION,10705,1469,MAIL,ANY_CLASS,ANY_FACTION),
        IncludeSet(COLLECTION,10705,1468,PLATE,ANY_CLASS,ANY_FACTION),
    }
    AddSetsToDatabase(VERSION, COLLECTION, sets)
end

local function GetExpansionAppearances()
    local COLLECTION, VERSION = SetCollector.EXPANSION, 70000
    local sets = {
        -- Legion Invasions (Pre-Patch)
        IncludeSet(COLLECTION,10700,160,CLOTH,ANY_CLASS,ANY_FACTION), -- Back 31718,79539
        IncludeSet(COLLECTION,10700,159,LEATHER,ANY_CLASS,ANY_FACTION),
        IncludeSet(COLLECTION,10700,158,MAIL,ANY_CLASS,ANY_FACTION),
        IncludeSet(COLLECTION,10700,157,PLATE,ANY_CLASS,ANY_FACTION),
        -- Order Hall Sets
        IncludeSet(COLLECTION,10701,550,PLATE,DEATHKNIGHT,ANY_FACTION),
        IncludeSet(COLLECTION,10701,548,LEATHER,DEMONHUNTER,ANY_FACTION),
        IncludeSet(COLLECTION,10701,549,LEATHER,DRUID,ANY_FACTION),
        IncludeSet(COLLECTION,10701,532,MAIL,HUNTER,ANY_FACTION),
        IncludeSet(COLLECTION,10701,516,CLOTH,MAGE,ANY_FACTION),
        IncludeSet(COLLECTION,10701,497,LEATHER,MONK,ANY_FACTION),
        IncludeSet(COLLECTION,10701,496,PLATE,PALADIN,ANY_FACTION),
        IncludeSet(COLLECTION,10701,330,CLOTH,PRIEST,ANY_FACTION),
        IncludeSet(COLLECTION,10701,464,LEATHER,ROGUE,ANY_FACTION),
        IncludeSet(COLLECTION,10701,430,MAIL,SHAMAN,ANY_FACTION),
        IncludeSet(COLLECTION,10701,448,CLOTH,WARLOCK,ANY_FACTION),
        IncludeSet(COLLECTION,10701,447,PLATE,WARRIOR,ANY_FACTION),
    }
    AddSetsToDatabase(VERSION, COLLECTION, sets)
end

local function GetLegendaries()
    local col = SetCollector.LEGENDARY
    local set = ""
end

local function GetOtherAppearances()
    local COLLECTION, VERSION = SetCollector.OTHER, 70000
    local sets = {
        -- Time Keeper
        IncludeSet(COLLECTION,10703,1457,CLOTH,ANY_CLASS,ANY_FACTION),
        IncludeSet(COLLECTION,10703,1459,LEATHER,ANY_CLASS,ANY_FACTION),
        IncludeSet(COLLECTION,10703,1458,MAIL,ANY_CLASS,ANY_FACTION),
        IncludeSet(COLLECTION,10703,1456,PLATE,ANY_CLASS,ANY_FACTION)
    }
    AddSetsToDatabase(VERSION, COLLECTION, sets)
end

local function GetPvPAppearances()
    local COLLECTION, VERSION = SetCollector.PVP, 70000
    -- Seasons 1 & 2
    local sets = {
        -- Alliance
        IncludeSet(COLLECTION,10701,1106,PLATE,DEATHKNIGHT,ALLIANCE,1108,1163),
        IncludeSet(COLLECTION,10701,1110,LEATHER,DEMONHUNTER,ALLIANCE,1112,1167),
        IncludeSet(COLLECTION,10701,1098,LEATHER,DRUID,ALLIANCE,1100,1168),
        IncludeSet(COLLECTION,10701,1113,MAIL,HUNTER,ALLIANCE,409,1115),
        IncludeSet(COLLECTION,10701,1094,CLOTH,MAGE,ALLIANCE,1096,1137),
        IncludeSet(COLLECTION,10701,1117,LEATHER,MONK,ALLIANCE,1119,1169),
        IncludeSet(COLLECTION,10701,1121,PLATE,PALADIN,ALLIANCE,1123,1164),
        IncludeSet(COLLECTION,10701,388,CLOTH,PRIEST,ALLIANCE,392,1071),
        IncludeSet(COLLECTION,10701,1068,LEATHER,ROGUE,ALLIANCE,1125,1127),
        IncludeSet(COLLECTION,10701,1129,MAIL,SHAMAN,ALLIANCE,1131,1161),
        IncludeSet(COLLECTION,10701,1101,CLOTH,WARLOCK,ALLIANCE,1103,1158),
        IncludeSet(COLLECTION,10701,1133,PLATE,WARRIOR,ALLIANCE,1070,1135),
        -- Horde
        IncludeSet(COLLECTION,10701,1105,PLATE,DEATHKNIGHT,HORDE,1107,1165),
        IncludeSet(COLLECTION,10701,1109,LEATHER,DEMONHUNTER,HORDE,1111,1170),
        IncludeSet(COLLECTION,10701,1097,LEATHER,DRUID,HORDE,1099,1171),
        IncludeSet(COLLECTION,10701,1114,MAIL,HUNTER,HORDE,410,1116),
        IncludeSet(COLLECTION,10701,1093,CLOTH,MAGE,HORDE,1095,1159),
        IncludeSet(COLLECTION,10701,1118,LEATHER,MONK,HORDE,1120,1172),
        IncludeSet(COLLECTION,10701,1122,PLATE,PALADIN,HORDE,1124,1166),
        IncludeSet(COLLECTION,10701,390,CLOTH,PRIEST,HORDE,393,1072),
        IncludeSet(COLLECTION,10701,1126,LEATHER,ROGUE,HORDE,1067,1128),
        IncludeSet(COLLECTION,10701,1130,MAIL,SHAMAN,HORDE,1132,1162),
        IncludeSet(COLLECTION,10701,1102,CLOTH,WARLOCK,HORDE,1104,1160),
        IncludeSet(COLLECTION,10701,1134,PLATE,WARRIOR,HORDE,1069,1136),
    }
    AddSetsToDatabase(VERSION, COLLECTION, sets)
    -- Seasons 3 & 4
    sets = {
        -- Alliance
        IncludeSet(COLLECTION,10702,1265,PLATE,DEATHKNIGHT,ALLIANCE,1267,1292),
        IncludeSet(COLLECTION,10702,1262,LEATHER,DEMONHUNTER,ALLIANCE,1263,1290),
        IncludeSet(COLLECTION,10702,1257,LEATHER,DRUID,ALLIANCE,1259,1288),
        IncludeSet(COLLECTION,10702,1254,MAIL,HUNTER,ALLIANCE,1255,1286),
        IncludeSet(COLLECTION,10702,1249,CLOTH,MAGE,ALLIANCE,1251,1284),
        IncludeSet(COLLECTION,10702,1245,LEATHER,MONK,ALLIANCE,1247,1282),
        IncludeSet(COLLECTION,10702,1241,PLATE,PALADIN,ALLIANCE,1243,1280),
        IncludeSet(COLLECTION,10702,389,CLOTH,PRIEST,ALLIANCE,395,1278),
        IncludeSet(COLLECTION,10702,1237,LEATHER,ROGUE,ALLIANCE,1239,1276),
        IncludeSet(COLLECTION,10702,1233,MAIL,SHAMAN,ALLIANCE,1235,1274),
        IncludeSet(COLLECTION,10702,1229,CLOTH,WARLOCK,ALLIANCE,1231,1272),
        IncludeSet(COLLECTION,10702,1225,PLATE,WARRIOR,ALLIANCE,1227,1270),
        -- Horde
        IncludeSet(COLLECTION,10702,1266,PLATE,DEATHKNIGHT,HORDE,1268,1291),
        IncludeSet(COLLECTION,10702,1261,LEATHER,DEMONHUNTER,HORDE,1264,1289),
        IncludeSet(COLLECTION,10702,1258,LEATHER,DRUID,HORDE,1260,1287),
        IncludeSet(COLLECTION,10702,1253,MAIL,HUNTER,HORDE,1256,1285),
        IncludeSet(COLLECTION,10702,1250,CLOTH,MAGE,HORDE,1252,1283),
        IncludeSet(COLLECTION,10702,1246,LEATHER,MONK,HORDE,1248,1281),
        IncludeSet(COLLECTION,10702,1242,PLATE,PALADIN,HORDE,1244,1279),
        IncludeSet(COLLECTION,10702,391,CLOTH,PRIEST,HORDE,394,1277),
        IncludeSet(COLLECTION,10702,1238,LEATHER,ROGUE,HORDE,1240,1275),
        IncludeSet(COLLECTION,10702,1234,MAIL,SHAMAN,HORDE,1236,1273),
        IncludeSet(COLLECTION,10702,1230,CLOTH,WARLOCK,HORDE,1232,1271),
        IncludeSet(COLLECTION,10702,1226,PLATE,WARRIOR,HORDE,1228,1269),
    }
    AddSetsToDatabase(VERSION, COLLECTION, sets)
    -- Seasons 5, 6 & 7
    sets = {
        -- Alliance
        IncludeSet(COLLECTION,10703,1400,PLATE,DEATHKNIGHT,ALLIANCE,1348,1352),
        IncludeSet(COLLECTION,10703,1402,LEATHER,DEMONHUNTER,ALLIANCE,1354,1358),
        IncludeSet(COLLECTION,10703,1404,LEATHER,DRUID,ALLIANCE,1360,1380),
        IncludeSet(COLLECTION,10703,1406,MAIL,HUNTER,ALLIANCE,1362,1382),
        IncludeSet(COLLECTION,10703,1408,CLOTH,MAGE,ALLIANCE,1364,1384),
        IncludeSet(COLLECTION,10703,1410,LEATHER,MONK,ALLIANCE,1366,1386),
        IncludeSet(COLLECTION,10703,1412,PLATE,PALADIN,ALLIANCE,1368,1388),
        IncludeSet(COLLECTION,10703,1414,CLOTH,PRIEST,ALLIANCE,1370,1390),
        IncludeSet(COLLECTION,10703,1416,LEATHER,ROGUE,ALLIANCE,1372,1392),
        IncludeSet(COLLECTION,10703,1418,MAIL,SHAMAN,ALLIANCE,1374,1394),
        IncludeSet(COLLECTION,10703,1420,CLOTH,WARLOCK,ALLIANCE,1376,1396),
        IncludeSet(COLLECTION,10703,1422,PLATE,WARRIOR,ALLIANCE,1378,1399),
        -- Horde
        IncludeSet(COLLECTION,10703,1401,PLATE,DEATHKNIGHT,HORDE,1349,1353),
        IncludeSet(COLLECTION,10703,1403,LEATHER,DEMONHUNTER,HORDE,1355,1359),
        IncludeSet(COLLECTION,10703,1405,LEATHER,DRUID,HORDE,1361,1381),
        IncludeSet(COLLECTION,10703,1407,MAIL,HUNTER,HORDE,1363,1383),
        IncludeSet(COLLECTION,10703,1409,CLOTH,MAGE,HORDE,1365,1385),
        IncludeSet(COLLECTION,10703,1411,LEATHER,MONK,HORDE,1367,1387),
        IncludeSet(COLLECTION,10703,1413,PLATE,PALADIN,HORDE,1369,1389),
        IncludeSet(COLLECTION,10703,1415,CLOTH,PRIEST,HORDE,1371,1391),
        IncludeSet(COLLECTION,10703,1417,LEATHER,ROGUE,HORDE,1373,1393),
        IncludeSet(COLLECTION,10703,1419,MAIL,SHAMAN,HORDE,1375,1395),
        IncludeSet(COLLECTION,10703,1421,CLOTH,WARLOCK,HORDE,1377,1397),
        IncludeSet(COLLECTION,10703,1423,PLATE,WARRIOR,HORDE,1398,1423),
    }
    AddSetsToDatabase(VERSION, COLLECTION, sets)
end

local function GetRaidAppearances()
    
    local COLLECTION, VERSION = SetCollector.RAID, 70000

    -- The Nighthold
    VERSION = 70000
    local sets = {
        IncludeSet(COLLECTION,10701,1002,PLATE,DEATHKNIGHT,ANY_FACTION,1003,1004,1005),
        IncludeSet(COLLECTION,10701,998,LEATHER,DEMONHUNTER,ANY_FACTION,999,1000,1001),
        IncludeSet(COLLECTION,10701,994,LEATHER,DRUID,ANY_FACTION,995,996,997),
        IncludeSet(COLLECTION,10701,990,MAIL,HUNTER,ANY_FACTION,991,992,993),
        IncludeSet(COLLECTION,10701,986,CLOTH,MAGE,ANY_FACTION,987,988,989),
        IncludeSet(COLLECTION,10701,982,LEATHER,MONK,ANY_FACTION,983,984,985),
        IncludeSet(COLLECTION,10701,978,PLATE,PALADIN,ANY_FACTION,979,980,981),
        IncludeSet(COLLECTION,10701,308,CLOTH,PRIEST,ANY_FACTION,309,311,322),
        IncludeSet(COLLECTION,10701,942,LEATHER,ROGUE,ANY_FACTION,943,944,945),
        IncludeSet(COLLECTION,10701,933,MAIL,SHAMAN,ANY_FACTION,934,935,936),
        IncludeSet(COLLECTION,10701,315,CLOTH,WARLOCK,ANY_FACTION,316,321,941),
        IncludeSet(COLLECTION,10701,937,PLATE,WARRIOR,ANY_FACTION,938,939,940),
    }
    AddSetsToDatabase(VERSION, COLLECTION, sets)

    -- Tomb of Sargeras
    VERSION = 70200
    local sets = {
        IncludeSet(COLLECTION,10702,1337,PLATE,DEATHKNIGHT,ANY_FACTION,1338,1339,1340),
        IncludeSet(COLLECTION,10702,1333,LEATHER,DEMONHUNTER,ANY_FACTION,1334,1335,1336),
        IncludeSet(COLLECTION,10702,1329,LEATHER,DRUID,ANY_FACTION,1330,1331,1332),
        IncludeSet(COLLECTION,10702,1325,MAIL,HUNTER,ANY_FACTION,1326,1327,1328),
        IncludeSet(COLLECTION,10702,1321,CLOTH,MAGE,ANY_FACTION,1322,1323,1324),
        IncludeSet(COLLECTION,10702,1317,LEATHER,MONK,ANY_FACTION,1318,1319,1320),
        IncludeSet(COLLECTION,10702,1313,PLATE,PALADIN,ANY_FACTION,1314,1315,1316),
        IncludeSet(COLLECTION,10702,1309,CLOTH,PRIEST,ANY_FACTION,1310,1312,1342),
        IncludeSet(COLLECTION,10702,1305,LEATHER,ROGUE,ANY_FACTION,1306,1307,1308),
        IncludeSet(COLLECTION,10702,1301,MAIL,SHAMAN,ANY_FACTION,1302,1303,1304),
        IncludeSet(COLLECTION,10702,1297,CLOTH,WARLOCK,ANY_FACTION,1298,1299,1300),
        IncludeSet(COLLECTION,10702,1293,PLATE,WARRIOR,ANY_FACTION,1294,1295,1296),
    }
    AddSetsToDatabase(VERSION, COLLECTION, sets)

    -- Antorus, the Burning Throne
    VERSION = 70300
    local sets = {
        IncludeSet(COLLECTION,10703,1472,PLATE,DEATHKNIGHT,ANY_FACTION,1473,1474,1475),
        IncludeSet(COLLECTION,10703,1476,LEATHER,DEMONHUNTER,ANY_FACTION,1477,1478,1479),
        IncludeSet(COLLECTION,10703,1480,LEATHER,DRUID,ANY_FACTION,1481,1482,1483),
        IncludeSet(COLLECTION,10703,1484,MAIL,HUNTER,ANY_FACTION,1485,1486,1487),
        IncludeSet(COLLECTION,10703,1488,CLOTH,MAGE,ANY_FACTION,1489,1490,1491),
        IncludeSet(COLLECTION,10703,1492,LEATHER,MONK,ANY_FACTION,1493,1494,1495),
        IncludeSet(COLLECTION,10703,1496,PLATE,PALADIN,ANY_FACTION,1497,1498,1499),
        IncludeSet(COLLECTION,10703,1500,CLOTH,PRIEST,ANY_FACTION,1501,1502,1503),
        IncludeSet(COLLECTION,10703,1504,LEATHER,ROGUE,ANY_FACTION,1505,1506,1507),
        IncludeSet(COLLECTION,10703,1508,MAIL,SHAMAN,ANY_FACTION,1509,1510,1511),
        IncludeSet(COLLECTION,10703,1512,CLOTH,WARLOCK,ANY_FACTION,1513,1514,1515),
        IncludeSet(COLLECTION,10703,1516,PLATE,WARRIOR,ANY_FACTION,1517,1518,1519),
    }
    AddSetsToDatabase(VERSION, COLLECTION, sets)
end

--
--    GLOBAL FUNCTIONS
--

function SetCollector:GetVersion07Appearances(expansion)
    if expansion.v07 then
        -- Common
        --GetCraftedAppearances()
        GetDungeonAppearances()
        GetLegendaries()
        GetExpansionAppearances()
        GetOtherAppearances()
        GetPvPAppearances()
        GetRaidAppearances()
    end
end

function SetCollector:GetVersion07Status()
    return SetCollector:GetExpansionStatus("7")
end

function SetCollector:SetVersion07Status()
    SetCollector:SetExpansionStatus("7")
end
